@@ -109,9 +109,9 @@ static int usage(int exitcode) {
   std::cout << "\nAdditional options:\n";
   std::cout << "    --no-dummy-server: Use the currently running X server "
                "for testing\n";
-  std::cout << "    --xorg-conf: Path to xorg dummy configuration file\n";
+  std::cout << "    --xorg-conf: Path to xorg configuration file\n";
   std::cout << "    --server: Path to X server executable\n";
-  std::cout << "    --xorg-display: xorg dummy display port\n";
+  std::cout << "    --xorg-display: xorg display port\n";
   std::cout << "    --xorg-logfile: xorg logfile filename. See -logfile in \"man Xorg\".\n"
                "                    Its default value is " DEFAULT_XORG_LOGFILE ".\n";
   return exitcode;
